# BatteryDataExtractor
BatteryDataExtractor is a battery-aware text-mining software embedded with BERT models for automatically extracting chemical information from scientific literature. Full details available at [Documentation](https://batterydataextractor.readthedocs.io/en/latest/index.html).

### Installation 
Note: this command will be available after the paper has been accepted for publication:
```angular2html
pip install batterydataextractor
```
### Features
   * Open-source battery-specific literature-mining toolkit
   * BERT-based token-classification models: abbreviation detection, part-of-speech tagging, chemical-named-entity recognition
   * Double-turn question-answering model for the data extraction of materials and properties
   * State-of-the-art performance on downstream evaluation data sets
   * Updated NLP plugins: new web scrapers, document readers, and tokenizers
   * New options: database auto-saving, original text-saving, and device-selection

### Citing

BatteryDataExtractor: battery-aware text-mining software embedded with BERT models
